# Setup and Deployment - Linux

*Note: This documentation assumes a setup in a brand new LAMP environment or similar. Some things may differ depending on environtment. It also assumes an Ubuntu/Ubuntu flavour based setup.*

* * *

### LAMP Stack Setup

1.  Set up a standard LAMP stack in Ubuntu. [LinuxBabe](https://www.linuxbabe.com/) often has fantastic directions.

* * *

### Additional PHP Setup

You'll need additional PHP packages not usually installed with the regular PHP setup.

1.  The PHP developer package adds needed files to make and build the sqlsrv drivers.
    `sudo apt install php7.4-dev`
2.  The PHP Pear package adds functionality to download, build, and install the sqlsrv drivers.
    `sudo apt install php-pear`
3.  You need a specific file, sql.h, to build the sqlsrv drivers. It's found in the Unix ODBC developer package.
    `sudo apt install unixodbc-dev`
4.  Install Composer for PHP addons and modules.
    `sudo apt install composer`
5.  Use Composer to install PHPMailer.
    `composer require phpmailer/phpmailer`
6.  Copy the `vendor` folder from ~ to `/var/www/html/`

* * *

### Installing Microsoft ODBC Driver for SQL Server for Linux

*Note: Make sure curl is installed. If needed, it can be installed via:*
`sudo apt install curl`

1.  Add Microsoft apt key information.
    `sudo su`
    `curl https://packages.microsoft.com/keys/microsoft.asc | apt-key add -`
2.  Add the repo information for ODBC 17.
    
    ```
    curl https://packages.microsoft.com/config/ubuntu/20.04/prod.list > /etc/apt/sources.list.d/mssql-release.list
    ```
    
3.  Exit from su, and install the driver.
    `exit`
    `sudo apt-get update`
    `sudo ACCEPT_EULA=Y apt-get install msodbcsql17`

* * *

### Install PHP Drivers for SQL Server

1.  Make sure all the above steps have been completed, then roll through the following.
    
    `sudo pecl install sqlsrv`
    
    `sudo pecl install pdo_sqlsrv`
    
    `sudo su`
    
    `printf "; priority=20\nextension=sqlsrv.so\n" > /etc/php/7.4/mods-available/sqlsrv.ini`
    
    `printf "; priority=30\nextension=pdo_sqlsrv.so\n" > /etc/php/7.4/mods-available/pdo_sqlsrv.ini`
    
    `exit`
    
    `sudo phpenmod -v 7.4 sqlsrv pdo_sqlsrv`
    
2.  Set up Apache mods.
    
    `sudo su`
    
    `a2dismod mpm_event`
    
    `a2enmod mpm_prefork`
    
    `a2enmod php7.4`
    
    `exit`
    
3.  Restart Apache
    
    `sudo systemctl restart apache2`
    
4.  Check the installation using the CheckMSSQLConnection.php file
    

* * *

### References

- [Linux and macOS Installation Tutorial for the Microsoft Drivers for PHP for SQL Server](https://docs.microsoft.com/en-us/sql/connect/php/installation-tutorial-linux-mac?view=sql-server-ver15)
- [Install the Microsoft ODBC driver for SQL Server (Linux)](https://docs.microsoft.com/en-us/sql/connect/odbc/linux-mac/installing-the-microsoft-odbc-driver-for-sql-server?view=sql-server-ver15#ubuntu17)
- [How to Install LAMP Stack on Ubuntu 20.04 Server/Desktop](https://www.linuxbabe.com/ubuntu/install-lamp-stack-ubuntu-20-04-server-desktop)